pub struct IrqHandler { /* private fields */ }Implementations
Sourceimpl IrqHandler
impl IrqHandler
pub fn enable(&self)
pub fn disable(&self)
Sourcepub fn handle_irq(&mut self) -> Event
pub fn handle_irq(&mut self) -> Event
Handles a device interrupt and returns queue events without waking task wakers.
This is the IRQ top-half entry: it only asks the portable driver to
identify/acknowledge the interrupt source and publish queue event bits.
Runtime queue wakers must be invoked later from task/deferred context
through handle.
Sourcepub fn handle(&mut self)
pub fn handle(&mut self)
Handles a device interrupt and wakes registered queue waiters.
Use this only from task/deferred context. Hard IRQ callbacks should call
handle_irq and defer waker execution.
pub fn enable_irq(&self)
pub fn disable_irq(&self)
pub fn is_irq_enabled(&self) -> bool